com.cognitect.vase.datomic


connectclj

(connect uri)

Given a Datomic URI, attempt to create the database and connect to it, returning the connection.

Given a Datomic URI, attempt to create the database and connect to it,
returning the connection.
sourceraw docstring

ensure-schemaclj

(ensure-schema conn norms)
source

insert-datomicclj

(insert-datomic conn)

Provide a Datomic conn and db in all incoming requests

Provide a Datomic conn and db in all incoming requests
sourceraw docstring

new-db-uriclj

(new-db-uri)
source

normalize-norm-keysclj

(normalize-norm-keys norms)
source

cljdoc builds & hosts documentation for Clojure/Script libraries