(connect uri)Given a Datomic URI, attempt to create the database and connect to it, returning the connection.
Given a Datomic URI, attempt to create the database and connect to it, returning the connection.
(insert-datomic conn)Provide a Datomic conn and db in all incoming requests
Provide a Datomic conn and db in all incoming requests
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |